@@ -4,7 +4,9 @@ set -euxo pipefail
 MISE_VERSION=$(./scripts/get-version.sh)
 
 mkdir -p mise/lib
-touch mise/lib/.disable-self-update
+cat >mise/lib/mise-self-update-instructions.toml <<'TOML'
+message = "To update mise from the APT repository, run:\n\n  sudo apt update && sudo apt install --only-upgrade mise\n"
+TOML
 
 tar -xvJf "dist/mise-$MISE_VERSION-linux-x64.tar.xz"
 fpm -s dir -t deb \
@@ -16,7 +18,7 @@ fpm -s dir -t deb \
 	--url "https://github.com/jdx/mise" \
 	--maintainer "Jeff Dickey @jdx" \
 	mise/bin/mise=/usr/bin/mise \
-	mise/lib/.disable-self-update=/usr/lib/mise/.disable-self-update \
+	mise/lib/mise-self-update-instructions.toml=/usr/lib/mise/mise-self-update-instructions.toml \
 	mise/man/man1/mise.1=/usr/share/man/man1/mise.1
 
 tar -xvJf "dist/mise-$MISE_VERSION-linux-arm64.tar.xz"
@@ -29,7 +31,7 @@ fpm -s dir -t deb \
 	--url "https://github.com/jdx/mise" \
 	--maintainer "Jeff Dickey @jdx" \
 	mise/bin/mise=/usr/bin/mise \
-	mise/lib/.disable-self-update=/usr/lib/mise/.disable-self-update \
+	mise/lib/mise-self-update-instructions.toml=/usr/lib/mise/mise-self-update-instructions.toml \
 	mise/man/man1/mise.1=/usr/share/man/man1/mise.1
 
 mkdir -p dist/deb/pool/main
