@@ -1,4 +1,5 @@
 use crate::backend::backend_type::BackendType;
+use crate::backend::platform_target::PlatformTarget;
 use crate::backend::static_helpers::get_filename_from_url;
 use crate::cli::args::BackendArg;
 use crate::cli::version::{ARCH, OS};
@@ -6,13 +7,15 @@ use crate::config::Settings;
 use crate::file::TarOptions;
 use crate::http::HTTP;
 use crate::install_context::InstallContext;
+use crate::lockfile::PlatformInfo;
 use crate::path::{Path, PathBuf, PathExt};
 use crate::plugins::VERSION_REGEX;
 use crate::registry::REGISTRY;
 use crate::toolset::ToolVersion;
 use crate::{
     aqua::aqua_registry_wrapper::{
-        AQUA_REGISTRY, AquaChecksumType, AquaMinisignType, AquaPackage, AquaPackageType,
+        AQUA_REGISTRY, AquaChecksum, AquaChecksumType, AquaMinisignType, AquaPackage,
+        AquaPackageType,
     },
     cache::{CacheManager, CacheManagerBuilder},
 };
@@ -81,15 +84,27 @@ impl Backend for AquaBackend {
         ctx: &InstallContext,
         mut tv: ToolVersion,
     ) -> Result<ToolVersion> {
-        let tag = self
-            .get_version_tags()
-            .await
-            .ok()
-            .into_iter()
-            .flatten()
-            .find(|(version, _)| version == &tv.version)
-            .map(|(_, tag)| tag);
-        let mut v = tag.cloned().unwrap_or_else(|| tv.version.clone());
+        // Check if URL already exists in lockfile platforms first
+        // This allows us to skip API calls when lockfile has the URL
+        let platform_key = self.get_platform_key();
+        let existing_platform = tv
+            .lock_platforms
+            .get(&platform_key)
+            .and_then(|asset| asset.url.clone());
+
+        // Skip get_version_tags() API call if we have lockfile URL
+        let tag = if existing_platform.is_some() {
+            None // We'll determine version from URL instead
+        } else {
+            self.get_version_tags()
+                .await
+                .ok()
+                .into_iter()
+                .flatten()
+                .find(|(version, _)| version == &tv.version)
+                .map(|(_, tag)| tag.clone())
+        };
+        let mut v = tag.clone().unwrap_or_else(|| tv.version.clone());
         let mut v_prefixed =
             (tag.is_none() && !tv.version.starts_with('v')).then(|| format!("v{v}"));
         let versions = match &v_prefixed {
@@ -103,22 +118,34 @@ impl Backend for AquaBackend {
             && !v.starts_with(prefix)
         {
             v = format!("{prefix}{v}");
-            v_prefixed = v_prefixed.map(|v| format!("{prefix}{v}"));
+            // Don't add prefix to v_prefixed if it already starts with the prefix
+            v_prefixed = v_prefixed.map(|vp| {
+                if vp.starts_with(prefix) {
+                    vp
+                } else {
+                    format!("{prefix}{vp}")
+                }
+            });
         }
         validate(&pkg)?;
-
-        // Check if URL already exists in lockfile platforms first
-        let platform_key = self.get_platform_key();
-        let existing_platform = tv
-            .lock_platforms
-            .get(&platform_key)
-            .and_then(|asset| asset.url.clone());
         let (url, v, filename, api_digest) =
             if let Some(existing_platform) = existing_platform.clone() {
                 let url = existing_platform;
                 let filename = get_filename_from_url(&url);
                 // Determine which version variant was used based on the URL or filename
-                let v = if url.contains(&format!("v{}", tv.version))
+                // Check for version_prefix (e.g., "jq-" for jq), "v" prefix, or raw version
+                let v = if let Some(prefix) = &pkg.version_prefix {
+                    let prefixed_version = format!("{prefix}{}", tv.version);
+                    if url.contains(&prefixed_version) || filename.contains(&prefixed_version) {
+                        prefixed_version
+                    } else if url.contains(&format!("v{}", tv.version))
+                        || filename.contains(&format!("v{}", tv.version))
+                    {
+                        format!("v{}", tv.version)
+                    } else {
+                        tv.version.clone()
+                    }
+                } else if url.contains(&format!("v{}", tv.version))
                     || filename.contains(&format!("v{}", tv.version))
                 {
                     format!("v{}", tv.version)
@@ -183,7 +210,10 @@ impl Backend for AquaBackend {
         _config: &Arc<Config>,
         tv: &ToolVersion,
     ) -> Result<Vec<PathBuf>> {
-        // TODO: instead of caching it would probably be better to create this as part of installation
+        if self.symlink_bins(tv) {
+            return Ok(vec![tv.install_path().join(".mise-bins")]);
+        }
+
         let cache = self
             .bin_path_caches
             .entry(tv.version.clone())
@@ -243,6 +273,108 @@ impl Backend for AquaBackend {
             })
             .collect()
     }
+
+    /// Resolve platform-specific lock information for any target platform.
+    /// This enables cross-platform lockfile generation without installation.
+    async fn resolve_lock_info(
+        &self,
+        tv: &ToolVersion,
+        target: &PlatformTarget,
+    ) -> Result<PlatformInfo> {
+        // Map Platform to Aqua's os/arch conventions
+        let target_os = match target.os_name() {
+            "macos" => "darwin",
+            other => other,
+        };
+        let target_arch = match target.arch_name() {
+            "x64" => "amd64",
+            other => other,
+        };
+
+        // Get version tag
+        let tag = self
+            .get_version_tags()
+            .await
+            .ok()
+            .into_iter()
+            .flatten()
+            .find(|(version, _)| version == &tv.version)
+            .map(|(_, tag)| tag);
+        let mut v = tag.cloned().unwrap_or_else(|| tv.version.clone());
+        let v_prefixed = (tag.is_none() && !tv.version.starts_with('v')).then(|| format!("v{v}"));
+        let versions = match &v_prefixed {
+            Some(v_prefixed) => vec![v.as_str(), v_prefixed.as_str()],
+            None => vec![v.as_str()],
+        };
+
+        // Get package with version for the target platform
+        let pkg = AQUA_REGISTRY
+            .package_with_version(&self.id, &versions)
+            .await?;
+        let pkg = pkg.with_version(&versions, target_os, target_arch);
+
+        // Apply version prefix if present
+        if let Some(prefix) = &pkg.version_prefix
+            && !v.starts_with(prefix)
+        {
+            v = format!("{prefix}{v}");
+        }
+
+        // Check if this platform is supported
+        if !is_platform_supported(&pkg.supported_envs, target_os, target_arch) {
+            debug!(
+                "aqua package {} does not support {}: supported_envs={:?}",
+                self.id,
+                target.to_key(),
+                pkg.supported_envs
+            );
+            return Ok(PlatformInfo::default());
+        }
+
+        // Get URL and checksum for the target platform
+        let (url, checksum) = match pkg.r#type {
+            AquaPackageType::GithubRelease => {
+                // For GitHub releases, we need to find the asset for the target platform
+                let asset_strs = pkg.asset_strs(&v, target_os, target_arch)?;
+                match self.github_release_asset(&pkg, &v, asset_strs).await {
+                    Ok((url, digest)) => (Some(url), digest),
+                    Err(e) => {
+                        debug!(
+                            "Failed to get GitHub release asset for {} on {}: {}",
+                            self.id,
+                            target.to_key(),
+                            e
+                        );
+                        (None, None)
+                    }
+                }
+            }
+            AquaPackageType::GithubArchive | AquaPackageType::GithubContent => {
+                (Some(self.github_archive_url(&pkg, &v)), None)
+            }
+            AquaPackageType::Http => (pkg.url(&v, target_os, target_arch).ok(), None),
+            _ => (None, None),
+        };
+
+        let name = url.as_ref().map(|u| get_filename_from_url(u));
+
+        // Try to get checksum from checksum file if not available from GitHub API
+        let checksum = match checksum {
+            Some(c) => Some(c),
+            None => self
+                .fetch_checksum_from_file(&pkg, &v, target_os, target_arch, name.as_deref())
+                .await
+                .ok()
+                .flatten(),
+        };
+
+        Ok(PlatformInfo {
+            url,
+            checksum,
+            size: None,
+            url_api: None,
+        })
+    }
 }
 
 impl AquaBackend {
@@ -364,6 +496,145 @@ impl AquaBackend {
         format!("https://github.com/{gh_id}/archive/refs/tags/{v}.tar.gz")
     }
 
+    /// Fetch checksum from a checksum file without downloading the actual tarball.
+    /// This is used for cross-platform lockfile generation.
+    async fn fetch_checksum_from_file(
+        &self,
+        pkg: &AquaPackage,
+        v: &str,
+        target_os: &str,
+        target_arch: &str,
+        filename: Option<&str>,
+    ) -> Result<Option<String>> {
+        let Some(checksum_config) = &pkg.checksum else {
+            return Ok(None);
+        };
+        if !checksum_config.enabled() {
+            return Ok(None);
+        }
+        let Some(filename) = filename else {
+            return Ok(None);
+        };
+
+        // Get the checksum file URL
+        let url = match checksum_config._type() {
+            AquaChecksumType::GithubRelease => {
+                let asset_strs = checksum_config.asset_strs(pkg, v, target_os, target_arch)?;
+                match self.github_release_asset(pkg, v, asset_strs).await {
+                    Ok((url, _)) => url,
+                    Err(e) => {
+                        debug!("Failed to get checksum file asset: {}", e);
+                        return Ok(None);
+                    }
+                }
+            }
+            AquaChecksumType::Http => checksum_config.url(pkg, v, target_os, target_arch)?,
+        };
+
+        // Download checksum file content
+        let checksum_content = match HTTP.get_text(&url).await {
+            Ok(content) => content,
+            Err(e) => {
+                debug!("Failed to download checksum file {}: {}", url, e);
+                return Ok(None);
+            }
+        };
+
+        // Parse checksum from file content
+        let checksum_str =
+            self.parse_checksum_from_content(&checksum_content, checksum_config, filename)?;
+
+        Ok(Some(format!(
+            "{}:{}",
+            checksum_config.algorithm(),
+            checksum_str
+        )))
+    }
+
+    /// Parse a checksum from checksum file content for a specific filename.
+    fn parse_checksum_from_content(
+        &self,
+        content: &str,
+        checksum_config: &AquaChecksum,
+        filename: &str,
+    ) -> Result<String> {
+        let mut checksum_file = content.to_string();
+
+        if checksum_config.file_format() == "regexp" {
+            let pattern = checksum_config.pattern();
+            if let Some(file_pattern) = &pattern.file {
+                let re = regex::Regex::new(file_pattern.as_str())?;
+                if let Some(line) = checksum_file
+                    .lines()
+                    .find(|l| re.captures(l).is_some_and(|c| c[1].to_string() == filename))
+                {
+                    checksum_file = line.to_string();
+                } else {
+                    debug!(
+                        "no line found matching {} in checksum file for {}",
+                        file_pattern, filename
+                    );
+                }
+            }
+            let re = regex::Regex::new(pattern.checksum.as_str())?;
+            if let Some(caps) = re.captures(checksum_file.as_str()) {
+                checksum_file = caps[1].to_string();
+            } else {
+                debug!(
+                    "no checksum found matching {} in checksum file",
+                    pattern.checksum
+                );
+            }
+        }
+
+        // Standard format: "<hash>  <filename>" or "<hash> *<filename>"
+        let checksum_str = checksum_file
+            .lines()
+            .filter_map(|l| {
+                let split = l.split_whitespace().collect_vec();
+                if split.len() == 2 {
+                    Some((
+                        split[0].to_string(),
+                        split[1]
+                            .rsplit_once('/')
+                            .map(|(_, f)| f)
+                            .unwrap_or(split[1])
+                            .trim_matches('*')
+                            .to_string(),
+                    ))
+                } else {
+                    None
+                }
+            })
+            .find(|(_, f)| f == filename)
+            .map(|(c, _)| c)
+            .unwrap_or(checksum_file);
+
+        let checksum_str = checksum_str
+            .split_whitespace()
+            .next()
+            .unwrap_or(&checksum_str);
+        Ok(checksum_str.to_string())
+    }
+
+    /// Download a URL to a path, or convert a local path string to PathBuf.
+    /// Returns the path where the file is located.
+    async fn download_url_to_path(
+        &self,
+        url: &str,
+        download_path: &Path,
+        ctx: &InstallContext,
+    ) -> Result<PathBuf> {
+        if url.starts_with("http") {
+            let path = download_path.join(get_filename_from_url(url));
+            HTTP.download_file(url, &path, Some(ctx.pr.as_ref()))
+                .await?;
+            Ok(path)
+        } else {
+            Ok(PathBuf::from(url))
+        }
+    }
+
     async fn download(
         &self,
         ctx: &InstallContext,
@@ -413,55 +684,9 @@ impl AquaBackend {
                 .await?;
             self.cosign_checksums(ctx, pkg, v, tv, &checksum_path, &download_path)
                 .await?;
-            let mut checksum_file = file::read_to_string(&checksum_path)?;
-            if checksum.file_format() == "regexp" {
-                let pattern = checksum.pattern();
-                if let Some(file) = &pattern.file {
-                    let re = regex::Regex::new(file.as_str())?;
-                    if let Some(line) = checksum_file
-                        .lines()
-                        .find(|l| re.captures(l).is_some_and(|c| c[1].to_string() == filename))
-                    {
-                        checksum_file = line.to_string();
-                    } else {
-                        debug!(
-                            "no line found matching {} in {} for {}",
-                            file, checksum_file, filename
-                        );
-                    }
-                }
-                let re = regex::Regex::new(pattern.checksum.as_str())?;
-                if let Some(caps) = re.captures(checksum_file.as_str()) {
-                    checksum_file = caps[1].to_string();
-                } else {
-                    debug!(
-                        "no checksum found matching {} in {}",
-                        pattern.checksum, checksum_file
-                    );
-                }
-            }
-            let checksum_str = checksum_file
-                .lines()
-                .filter_map(|l| {
-                    let split = l.split_whitespace().collect_vec();
-                    if split.len() == 2 {
-                        Some((
-                            split[0].to_string(),
-                            split[1]
-                                .rsplit_once('/')
-                                .map(|(_, f)| f)
-                                .unwrap_or(split[1])
-                                .trim_matches('*')
-                                .to_string(),
-                        ))
-                    } else {
-                        None
-                    }
-                })
-                .find(|(_, f)| f == filename)
-                .map(|(c, _)| c)
-                .unwrap_or(checksum_file);
-            let checksum_str = checksum_str.split_whitespace().next().unwrap();
+            let checksum_content = file::read_to_string(&checksum_path)?;
+            let checksum_str =
+                self.parse_checksum_from_content(&checksum_content, checksum, filename)?;
             let checksum_val = format!("{}:{}", checksum.algorithm(), checksum_str);
             // Now set the checksum after all borrows are done
             let platform_key = self.get_platform_key();
@@ -494,14 +719,11 @@ impl AquaBackend {
             let sig_path = match minisign._type() {
                 AquaMinisignType::GithubRelease => {
                     let asset = minisign.asset(pkg, v, os(), arch())?;
-                    let repo_owner = minisign
-                        .repo_owner
-                        .clone()
-                        .unwrap_or_else(|| pkg.repo_owner.clone());
-                    let repo_name = minisign
-                        .repo_name
-                        .clone()
-                        .unwrap_or_else(|| pkg.repo_name.clone());
+                    let (repo_owner, repo_name) = resolve_repo_info(
+                        minisign.repo_owner.as_ref(),
+                        minisign.repo_name.as_ref(),
+                        pkg,
+                    );
                     let url = github::get_release(&format!("{repo_owner}/{repo_name}"), v)
                         .await?
                         .assets
@@ -554,14 +776,8 @@ impl AquaBackend {
 
             // Download the provenance file
             let mut slsa_pkg = pkg.clone();
-            slsa_pkg.repo_owner = slsa
-                .repo_owner
-                .clone()
-                .unwrap_or_else(|| pkg.repo_owner.clone());
-            slsa_pkg.repo_name = slsa
-                .repo_name
-                .clone()
-                .unwrap_or_else(|| pkg.repo_name.clone());
+            (slsa_pkg.repo_owner, slsa_pkg.repo_name) =
+                resolve_repo_info(slsa.repo_owner.as_ref(), slsa.repo_name.as_ref(), pkg);
 
             let provenance_path = match slsa.r#type.as_deref().unwrap_or_default() {
                 "github_release" => {
@@ -731,14 +947,8 @@ impl AquaBackend {
             if let Some(key) = &cosign.key {
                 // Key-based verification
                 let mut key_pkg = pkg.clone();
-                key_pkg.repo_owner = key
-                    .repo_owner
-                    .clone()
-                    .unwrap_or_else(|| pkg.repo_owner.clone());
-                key_pkg.repo_name = key
-                    .repo_name
-                    .clone()
-                    .unwrap_or_else(|| pkg.repo_name.clone());
+                (key_pkg.repo_owner, key_pkg.repo_name) =
+                    resolve_repo_info(key.repo_owner.as_ref(), key.repo_name.as_ref(), pkg);
                 let key_arg = match key.r#type.as_deref().unwrap_or_default() {
                     "github_release" => {
                         let asset_strs = key.asset_strs(pkg, v, os(), arch())?;
@@ -759,26 +969,18 @@ impl AquaBackend {
                 };
                 if !key_arg.is_empty() {
                     // Download or locate the public key
-                    let key_path = if key_arg.starts_with("http") {
-                        let key_path = download_path.join(get_filename_from_url(&key_arg));
-                        HTTP.download_file(&key_arg, &key_path, Some(ctx.pr.as_ref()))
-                            .await?;
-                        key_path
-                    } else {
-                        PathBuf::from(key_arg)
-                    };
+                    let key_path = self
+                        .download_url_to_path(&key_arg, download_path, ctx)
+                        .await?;
 
                     // Download signature if specified
                     let sig_path = if let Some(signature) = &cosign.signature {
                         let mut sig_pkg = pkg.clone();
-                        sig_pkg.repo_owner = signature
-                            .repo_owner
-                            .clone()
-                            .unwrap_or_else(|| pkg.repo_owner.clone());
-                        sig_pkg.repo_name = signature
-                            .repo_name
-                            .clone()
-                            .unwrap_or_else(|| pkg.repo_name.clone());
+                        (sig_pkg.repo_owner, sig_pkg.repo_name) = resolve_repo_info(
+                            signature.repo_owner.as_ref(),
+                            signature.repo_name.as_ref(),
+                            pkg,
+                        );
                         let sig_arg = match signature.r#type.as_deref().unwrap_or_default() {
                             "github_release" => {
                                 let asset_strs = signature.asset_strs(pkg, v, os(), arch())?;
@@ -798,14 +1000,8 @@ impl AquaBackend {
                             }
                         };
                         if !sig_arg.is_empty() {
-                            if sig_arg.starts_with("http") {
-                                let sig_path = download_path.join(get_filename_from_url(&sig_arg));
-                                HTTP.download_file(&sig_arg, &sig_path, Some(ctx.pr.as_ref()))
-                                    .await?;
-                                sig_path
-                            } else {
-                                PathBuf::from(sig_arg)
-                            }
+                            self.download_url_to_path(&sig_arg, download_path, ctx)
+                                .await?
                         } else {
                             // Default signature path
                             checksum_path.with_extension("sig")
@@ -839,14 +1035,8 @@ impl AquaBackend {
             } else if let Some(bundle) = &cosign.bundle {
                 // Bundle-based keyless verification
                 let mut bundle_pkg = pkg.clone();
-                bundle_pkg.repo_owner = bundle
-                    .repo_owner
-                    .clone()
-                    .unwrap_or_else(|| pkg.repo_owner.clone());
-                bundle_pkg.repo_name = bundle
-                    .repo_name
-                    .clone()
-                    .unwrap_or_else(|| pkg.repo_name.clone());
+                (bundle_pkg.repo_owner, bundle_pkg.repo_name) =
+                    resolve_repo_info(bundle.repo_owner.as_ref(), bundle.repo_name.as_ref(), pkg);
                 let bundle_arg = match bundle.r#type.as_deref().unwrap_or_default() {
                     "github_release" => {
                         let asset_strs = bundle.asset_strs(pkg, v, os(), arch())?;
@@ -868,14 +1058,9 @@ impl AquaBackend {
                     }
                 };
                 if !bundle_arg.is_empty() {
-                    let bundle_path = if bundle_arg.starts_with("http") {
-                        let bundle_path = download_path.join(get_filename_from_url(&bundle_arg));
-                        HTTP.download_file(&bundle_arg, &bundle_path, Some(ctx.pr.as_ref()))
-                            .await?;
-                        bundle_path
-                    } else {
-                        PathBuf::from(bundle_arg)
-                    };
+                    let bundle_path = self
+                        .download_url_to_path(&bundle_arg, download_path, ctx)
+                        .await?;
 
                     // Verify with bundle (keyless)
                     match sigstore_verification::verify_cosign_signature(
@@ -1006,20 +1191,49 @@ impl AquaBackend {
             }
         }
 
-        for (src, dst) in self.srcs(pkg, tv)? {
+        let srcs = self.srcs(pkg, tv)?;
+        for (src, dst) in &srcs {
             if src != dst && src.exists() && !dst.exists() {
                 if cfg!(windows) {
-                    file::copy(&src, &dst)?;
+                    file::copy(src, dst)?;
                 } else {
                     let src = PathBuf::from(".").join(src.file_name().unwrap().to_str().unwrap());
-                    file::make_symlink(&src, &dst)?;
+                    file::make_symlink(&src, dst)?;
                 }
             }
         }
 
+        if self.symlink_bins(tv) {
+            self.create_symlink_bin_dir(tv, &srcs)?;
+        }
+
         Ok(())
     }
 
+    /// Creates a `.mise-bins` directory with symlinks only to the binaries defined in the aqua registry.
+    /// This prevents bundled dependencies (like Python in aws-cli) from being exposed on PATH.
+    fn create_symlink_bin_dir(&self, tv: &ToolVersion, srcs: &[(PathBuf, PathBuf)]) -> Result<()> {
+        let symlink_dir = tv.install_path().join(".mise-bins");
+        file::create_dir_all(&symlink_dir)?;
+
+        for (_, dst) in srcs {
+            if let Some(bin_name) = dst.file_name() {
+                let symlink_path = symlink_dir.join(bin_name);
+                if dst.exists() && !symlink_path.exists() {
+                    file::make_symlink_or_copy(dst, &symlink_path)?;
+                }
+            }
+        }
+        Ok(())
+    }
+
+    fn symlink_bins(&self, tv: &ToolVersion) -> bool {
+        tv.request
+            .options()
+            .get("symlink_bins")
+            .is_some_and(|v| v == "true" || v == "1")
+    }
+
     fn srcs(&self, pkg: &AquaPackage, tv: &ToolVersion) -> Result<Vec<(PathBuf, PathBuf)>> {
         let files: Vec<(PathBuf, PathBuf)> = pkg
             .files
@@ -1074,18 +1288,13 @@ fn validate(pkg: &AquaPackage) -> Result<()> {
     if let Some(message) = &pkg.error_message {
         bail!("{}", message);
     }
-    let envs: HashSet<&str> = pkg.supported_envs.iter().map(|s| s.as_str()).collect();
-    let os = os();
-    let arch = arch();
-    let os_arch = format!("{os}/{arch}");
-    let mut myself: HashSet<&str> = ["all", os, arch, os_arch.as_str()].into();
-    if os == "windows" && arch == "arm64" {
-        // assume windows/arm64 is supported
-        myself.insert("windows/amd64");
-        myself.insert("amd64");
-    }
-    if !envs.is_empty() && envs.is_disjoint(&myself) {
-        bail!("unsupported env: {os_arch} (supported: {envs:?})");
+    if !is_platform_supported(&pkg.supported_envs, os(), arch()) {
+        bail!(
+            "unsupported env: {}/{} (supported: {:?})",
+            os(),
+            arch(),
+            pkg.supported_envs
+        );
     }
     match pkg.r#type {
         AquaPackageType::Cargo => {
@@ -1114,6 +1323,38 @@ fn validate(pkg: &AquaPackage) -> Result<()> {
     Ok(())
 }
 
+/// Resolve repo owner and name from an override config, falling back to pkg defaults.
+fn resolve_repo_info(
+    override_owner: Option<&String>,
+    override_name: Option<&String>,
+    pkg: &AquaPackage,
+) -> (String, String) {
+    let owner = override_owner
+        .cloned()
+        .unwrap_or_else(|| pkg.repo_owner.clone());
+    let name = override_name
+        .cloned()
+        .unwrap_or_else(|| pkg.repo_name.clone());
+    (owner, name)
+}
+
+/// Check if a platform is supported by the package's supported_envs.
+/// Returns true if supported, false if not.
+fn is_platform_supported(supported_envs: &[String], os: &str, arch: &str) -> bool {
+    if supported_envs.is_empty() {
+        return true;
+    }
+    let envs: HashSet<&str> = supported_envs.iter().map(|s| s.as_str()).collect();
+    let os_arch = format!("{os}/{arch}");
+    let mut myself: HashSet<&str> = ["all", os, arch, os_arch.as_str()].into();
+    // Windows ARM64 can typically run AMD64 binaries via emulation
+    if os == "windows" && arch == "arm64" {
+        myself.insert("windows/amd64");
+        myself.insert("amd64");
+    }
+    !envs.is_disjoint(&myself)
+}
+
 pub fn os() -> &'static str {
     if cfg!(target_os = "macos") {
         "darwin"
