@@ -1,20 +1,23 @@
 use crate::backend::asset_detector;
 use crate::backend::backend_type::BackendType;
-use crate::backend::static_helpers::lookup_platform_key;
+use crate::backend::platform_target::PlatformTarget;
 use crate::backend::static_helpers::{
-    get_filename_from_url, install_artifact, template_string, try_with_v_prefix, verify_artifact,
+    get_filename_from_url, install_artifact, lookup_platform_key, lookup_platform_key_for_target,
+    template_string, try_with_v_prefix, verify_artifact,
 };
 use crate::cli::args::BackendArg;
 use crate::config::Config;
-use crate::config::Settings;
+use crate::file;
 use crate::http::HTTP;
 use crate::install_context::InstallContext;
-use crate::toolset::ToolVersion;
+use crate::lockfile::PlatformInfo;
 use crate::toolset::ToolVersionOptions;
+use crate::toolset::{ToolRequest, ToolVersion};
 use crate::{backend::Backend, github, gitlab};
 use async_trait::async_trait;
 use eyre::Result;
 use regex::Regex;
+use std::collections::BTreeMap;
 use std::fmt::Debug;
 use std::sync::Arc;
 
@@ -51,29 +54,30 @@ impl Backend for UnifiedGitBackend {
         let repo = self.ba.tool_name();
         let opts = self.ba.opts();
         let api_url = self.get_api_url(&opts);
-        if self.is_gitlab() {
-            let releases = gitlab::list_releases_from_url(api_url.as_str(), &repo).await?;
-            Ok(releases
+        let version_prefix = opts.get("version_prefix");
+
+        // Get tag names from either GitHub or GitLab
+        let tag_names: Vec<String> = if self.is_gitlab() {
+            gitlab::list_releases_from_url(api_url.as_str(), &repo)
+                .await?
                 .into_iter()
-                .filter(|r| {
-                    opts.get("version_prefix")
-                        .is_none_or(|p| r.tag_name.starts_with(p))
-                })
-                .map(|r| self.strip_version_prefix(&r.tag_name))
-                .rev()
-                .collect())
+                .map(|r| r.tag_name)
+                .collect()
         } else {
-            let releases = github::list_releases_from_url(api_url.as_str(), &repo).await?;
-            Ok(releases
+            github::list_releases_from_url(api_url.as_str(), &repo)
+                .await?
                 .into_iter()
-                .filter(|r| {
-                    opts.get("version_prefix")
-                        .is_none_or(|p| r.tag_name.starts_with(p))
-                })
-                .map(|r| self.strip_version_prefix(&r.tag_name))
-                .rev()
-                .collect())
-        }
+                .map(|r| r.tag_name)
+                .collect()
+        };
+
+        // Apply common filtering and mapping
+        Ok(tag_names
+            .into_iter()
+            .filter(|tag| version_prefix.is_none_or(|p| tag.starts_with(p)))
+            .map(|tag| self.strip_version_prefix(&tag))
+            .rev()
+            .collect())
     }
 
     async fn install_version_(
@@ -87,16 +91,17 @@ impl Backend for UnifiedGitBackend {
 
         // Check if URL already exists in lockfile platforms first
         let platform_key = self.get_platform_key();
-        let asset = if let Some(existing_platform) = tv.lock_platforms.get(&platform_key) {
+
+        let asset = if let Some(existing_platform) = tv.lock_platforms.get(&platform_key)
+            && existing_platform.url.is_some()
+        {
             debug!(
                 "Using existing URL from lockfile for platform {}: {}",
                 platform_key,
                 existing_platform.url.clone().unwrap_or_default()
             );
             ReleaseAsset {
-                name: existing_platform.name.clone().unwrap_or_else(|| {
-                    get_filename_from_url(existing_platform.url.as_deref().unwrap_or(""))
-                }),
+                name: get_filename_from_url(existing_platform.url.as_deref().unwrap_or("")),
                 url: existing_platform.url.clone().unwrap_or_default(),
                 url_api: existing_platform.url_api.clone().unwrap_or_default(),
                 digest: None, // Don't use old digest from lockfile, will be fetched fresh if needed
@@ -118,14 +123,63 @@ impl Backend for UnifiedGitBackend {
         _config: &Arc<Config>,
         tv: &ToolVersion,
     ) -> Result<Vec<std::path::PathBuf>> {
+        if self.get_filter_bins(tv).is_some() {
+            return Ok(vec![tv.install_path().join(".mise-bins")]);
+        }
+
+        self.discover_bin_paths(tv)
+    }
+
+    fn resolve_lockfile_options(
+        &self,
+        request: &ToolRequest,
+        _target: &PlatformTarget,
+    ) -> BTreeMap<String, String> {
+        let opts = request.options();
+        let mut result = BTreeMap::new();
+
+        // These options affect which artifact is downloaded
+        for key in ["asset_pattern", "url", "version_prefix"] {
+            if let Some(value) = opts.get(key) {
+                result.insert(key.to_string(), value.clone());
+            }
+        }
+
+        result
+    }
+
+    /// Resolve platform-specific lock information for cross-platform lockfile generation.
+    /// This fetches release asset metadata including SHA256 digests from GitHub/GitLab API.
+    async fn resolve_lock_info(
+        &self,
+        tv: &ToolVersion,
+        target: &PlatformTarget,
+    ) -> Result<PlatformInfo> {
+        let repo = self.repo();
         let opts = tv.request.options();
-        if let Some(bin_path_template) =
-            lookup_platform_key(&opts, "bin_path").or_else(|| opts.get("bin_path").cloned())
-        {
-            let bin_path = template_string(&bin_path_template, tv);
-            Ok(vec![tv.install_path().join(&bin_path)])
-        } else {
-            self.discover_bin_paths(tv)
+        let api_url = self.get_api_url(&opts);
+
+        // Resolve asset for the target platform
+        let asset = self
+            .resolve_asset_url_for_target(tv, &opts, &repo, &api_url, target)
+            .await;
+
+        match asset {
+            Ok(asset) => Ok(PlatformInfo {
+                url: Some(asset.url),
+                url_api: Some(asset.url_api),
+                checksum: asset.digest,
+                size: None,
+            }),
+            Err(e) => {
+                debug!(
+                    "Failed to resolve asset for {} on {}: {}",
+                    self.ba.full(),
+                    target.to_key(),
+                    e
+                );
+                Ok(PlatformInfo::default())
+            }
         }
     }
 }
@@ -208,7 +262,6 @@ impl UnifiedGitBackend {
         // Store the asset URL and digest (if available) in the tool version
         let platform_key = self.get_platform_key();
         let platform_info = tv.lock_platforms.entry(platform_key).or_default();
-        platform_info.name = Some(asset.name.clone());
         platform_info.url = Some(asset.url.clone());
         platform_info.url_api = Some(asset.url_api.clone());
         if let Some(digest) = &asset.digest {
@@ -254,23 +307,61 @@ impl UnifiedGitBackend {
         install_artifact(tv, &file_path, opts, Some(ctx.pr.as_ref()))?;
         self.verify_checksum(ctx, tv, &file_path)?;
 
+        if let Some(bins) = self.get_filter_bins(tv) {
+            self.create_symlink_bin_dir(tv, bins)?;
+        }
+
         Ok(())
     }
 
     /// Discovers bin paths in the installation directory
     fn discover_bin_paths(&self, tv: &ToolVersion) -> Result<Vec<std::path::PathBuf>> {
+        let opts = tv.request.options();
+        if let Some(bin_path_template) =
+            lookup_platform_key(&opts, "bin_path").or_else(|| opts.get("bin_path").cloned())
+        {
+            let bin_path = template_string(&bin_path_template, tv);
+            return Ok(vec![tv.install_path().join(&bin_path)]);
+        }
+
         let bin_path = tv.install_path().join("bin");
         if bin_path.exists() {
             return Ok(vec![bin_path]);
         }
 
-        // Look for bin directory in subdirectories (for extracted archives)
+        // Check if the root directory contains an executable file
+        // If so, use the root directory as a bin path
+        if let Ok(entries) = std::fs::read_dir(tv.install_path()) {
+            for entry in entries.flatten() {
+                let path = entry.path();
+                if path.is_file() && file::is_executable(&path) {
+                    return Ok(vec![tv.install_path()]);
+                }
+            }
+        }
+
+        // Look for bin directory or executables in subdirectories (for extracted archives)
         let mut paths = Vec::new();
         if let Ok(entries) = std::fs::read_dir(tv.install_path()) {
             for entry in entries.flatten() {
-                let sub_bin_path = entry.path().join("bin");
-                if sub_bin_path.exists() {
-                    paths.push(sub_bin_path);
+                let path = entry.path();
+                if path.is_dir() {
+                    // Check for {subdir}/bin
+                    let sub_bin_path = path.join("bin");
+                    if sub_bin_path.exists() {
+                        paths.push(sub_bin_path);
+                    } else {
+                        // Check for executables directly in subdir (e.g., tusd_darwin_arm64/tusd)
+                        if let Ok(sub_entries) = std::fs::read_dir(&path) {
+                            for sub_entry in sub_entries.flatten() {
+                                let sub_path = sub_entry.path();
+                                if sub_path.is_file() && file::is_executable(&sub_path) {
+                                    paths.push(path.clone());
+                                    break;
+                                }
+                            }
+                        }
+                    }
                 }
             }
         }
@@ -282,16 +373,31 @@ impl UnifiedGitBackend {
         }
     }
 
-    /// Resolves the asset URL using either explicit patterns or auto-detection
+    /// Resolves the asset URL using either explicit patterns or auto-detection.
+    /// Delegates to resolve_asset_url_for_target with the current platform.
     async fn resolve_asset_url(
         &self,
         tv: &ToolVersion,
         opts: &ToolVersionOptions,
         repo: &str,
         api_url: &str,
+    ) -> Result<ReleaseAsset> {
+        let current_platform = PlatformTarget::from_current();
+        self.resolve_asset_url_for_target(tv, opts, repo, api_url, &current_platform)
+            .await
+    }
+
+    /// Resolves asset URL for a specific target platform (for cross-platform lockfile generation)
+    async fn resolve_asset_url_for_target(
+        &self,
+        tv: &ToolVersion,
+        opts: &ToolVersionOptions,
+        repo: &str,
+        api_url: &str,
+        target: &PlatformTarget,
     ) -> Result<ReleaseAsset> {
         // Check for direct platform-specific URLs first
-        if let Some(direct_url) = lookup_platform_key(opts, "url") {
+        if let Some(direct_url) = lookup_platform_key_for_target(opts, "url", target) {
             return Ok(ReleaseAsset {
                 name: get_filename_from_url(&direct_url),
                 url: direct_url.clone(),
@@ -304,39 +410,43 @@ impl UnifiedGitBackend {
         let version_prefix = opts.get("version_prefix").map(|s| s.as_str());
         if self.is_gitlab() {
             try_with_v_prefix(version, version_prefix, |candidate| async move {
-                self.resolve_gitlab_asset_url(tv, opts, repo, api_url, &candidate)
-                    .await
+                self.resolve_gitlab_asset_url_for_target(
+                    tv, opts, repo, api_url, &candidate, target,
+                )
+                .await
             })
             .await
         } else {
             try_with_v_prefix(version, version_prefix, |candidate| async move {
-                self.resolve_github_asset_url(tv, opts, repo, api_url, &candidate)
-                    .await
+                self.resolve_github_asset_url_for_target(
+                    tv, opts, repo, api_url, &candidate, target,
+                )
+                .await
             })
             .await
         }
     }
 
-    async fn resolve_github_asset_url(
+    /// Resolves GitHub asset URL for a specific target platform
+    async fn resolve_github_asset_url_for_target(
         &self,
         tv: &ToolVersion,
         opts: &ToolVersionOptions,
         repo: &str,
         api_url: &str,
         version: &str,
+        target: &PlatformTarget,
     ) -> Result<ReleaseAsset> {
         let release = github::get_release_for_url(api_url, repo, version).await?;
-
         let available_assets: Vec<String> = release.assets.iter().map(|a| a.name.clone()).collect();
 
-        // Try explicit pattern first, then fall back to auto-detection
-        if let Some(pattern) = lookup_platform_key(opts, "asset_pattern")
+        // Try explicit pattern first
+        if let Some(pattern) = lookup_platform_key_for_target(opts, "asset_pattern", target)
             .or_else(|| opts.get("asset_pattern").cloned())
         {
-            // Template the pattern with actual values
-            let templated_pattern = template_string(&pattern, tv);
+            // Template the pattern for the target platform
+            let templated_pattern = template_string_for_target(&pattern, tv, target);
 
-            // Find matching asset using pattern
             let asset = release
                 .assets
                 .into_iter()
@@ -357,8 +467,8 @@ impl UnifiedGitBackend {
             });
         }
 
-        // Fall back to auto-detection
-        let asset_name = self.auto_detect_asset(&available_assets)?;
+        // Fall back to auto-detection for target platform
+        let asset_name = asset_detector::detect_asset_for_target(&available_assets, target)?;
         let asset = self
             .find_asset_case_insensitive(&release.assets, &asset_name, |a| &a.name)
             .ok_or_else(|| {
@@ -377,16 +487,17 @@ impl UnifiedGitBackend {
         })
     }
 
-    async fn resolve_gitlab_asset_url(
+    /// Resolves GitLab asset URL for a specific target platform
+    async fn resolve_gitlab_asset_url_for_target(
         &self,
         tv: &ToolVersion,
         opts: &ToolVersionOptions,
         repo: &str,
         api_url: &str,
         version: &str,
+        target: &PlatformTarget,
     ) -> Result<ReleaseAsset> {
         let release = gitlab::get_release_for_url(api_url, repo, version).await?;
-
         let available_assets: Vec<String> = release
             .assets
             .links
@@ -394,14 +505,13 @@ impl UnifiedGitBackend {
             .map(|a| a.name.clone())
             .collect();
 
-        // Try explicit pattern first, then fall back to auto-detection
-        if let Some(pattern) = lookup_platform_key(opts, "asset_pattern")
+        // Try explicit pattern first
+        if let Some(pattern) = lookup_platform_key_for_target(opts, "asset_pattern", target)
             .or_else(|| opts.get("asset_pattern").cloned())
         {
-            // Template the pattern with actual values
-            let templated_pattern = template_string(&pattern, tv);
+            // Template the pattern for the target platform
+            let templated_pattern = template_string_for_target(&pattern, tv, target);
 
-            // Find matching asset using pattern
             let asset = release
                 .assets
                 .links
@@ -417,14 +527,14 @@ impl UnifiedGitBackend {
 
             return Ok(ReleaseAsset {
                 name: asset.name,
-                url: asset.url,
-                url_api: asset.direct_asset_url,
-                digest: None, // GitLab doesn't provide digests yet
+                url: asset.direct_asset_url.clone(),
+                url_api: asset.url,
+                digest: None, // GitLab doesn't provide digests
             });
         }
 
-        // Fall back to auto-detection
-        let asset_name = self.auto_detect_asset(&available_assets)?;
+        // Fall back to auto-detection for target platform
+        let asset_name = asset_detector::detect_asset_for_target(&available_assets, target)?;
         let asset = self
             .find_asset_case_insensitive(&release.assets.links, &asset_name, |a| &a.name)
             .ok_or_else(|| {
@@ -439,24 +549,7 @@ impl UnifiedGitBackend {
             name: asset.name.clone(),
             url: asset.direct_asset_url.clone(),
             url_api: asset.url.clone(),
-            digest: None, // GitLab doesn't provide digests yet
-        })
-    }
-
-    fn auto_detect_asset(&self, available_assets: &[String]) -> Result<String> {
-        let settings = Settings::get();
-        let picker = asset_detector::AssetPicker::new(
-            settings.os().to_string(),
-            settings.arch().to_string(),
-        );
-
-        picker.pick_best_asset(available_assets).ok_or_else(|| {
-            eyre::eyre!(
-                "No suitable asset found for current platform ({}-{})\nAvailable assets: {}",
-                settings.os(),
-                settings.arch(),
-                available_assets.join(", ")
-            )
+            digest: None, // GitLab doesn't provide digests
         })
     }
 
@@ -510,6 +603,94 @@ impl UnifiedGitBackend {
             tag_name.to_string()
         }
     }
+
+    fn get_filter_bins(&self, tv: &ToolVersion) -> Option<Vec<String>> {
+        let opts = tv.request.options();
+        let filter_bins = lookup_platform_key(&opts, "filter_bins")
+            .or_else(|| opts.get("filter_bins").cloned())?;
+
+        Some(
+            filter_bins
+                .split(',')
+                .map(|s| s.trim().to_string())
+                .filter(|s| !s.is_empty())
+                .collect(),
+        )
+    }
+
+    /// Creates a `.mise-bins` directory with symlinks only to the binaries specified in filter_bins.
+    fn create_symlink_bin_dir(&self, tv: &ToolVersion, bins: Vec<String>) -> Result<()> {
+        let symlink_dir = tv.install_path().join(".mise-bins");
+        file::create_dir_all(&symlink_dir)?;
+
+        // Find where the actual binaries are
+        let install_path = tv.install_path();
+        let bin_paths = self.discover_bin_paths(tv)?;
+
+        // Collect all possible source directories (install root + discovered bin paths)
+        let mut src_dirs = bin_paths;
+        if !src_dirs.contains(&install_path) {
+            src_dirs.push(install_path);
+        }
+
+        for bin_name in bins {
+            // Find the binary in any of the source directories
+            let mut found = false;
+            for dir in &src_dirs {
+                let src = dir.join(&bin_name);
+                if src.exists() {
+                    let dst = symlink_dir.join(&bin_name);
+                    if !dst.exists() {
+                        file::make_symlink_or_copy(&src, &dst)?;
+                    }
+                    found = true;
+                    break;
+                }
+            }
+
+            if !found {
+                warn!(
+                    "Could not find binary '{}' in install directories. Available paths: {:?}",
+                    bin_name, src_dirs
+                );
+            }
+        }
+        Ok(())
+    }
+}
+
+/// Templates a string pattern with version and target platform values
+fn template_string_for_target(template: &str, tv: &ToolVersion, target: &PlatformTarget) -> String {
+    let version = &tv.version;
+    let os = target.os_name();
+    let arch = target.arch_name();
+
+    // Map to common naming conventions
+    let darwin_os = if os == "macos" { "darwin" } else { os };
+    let amd64_arch = match arch {
+        "x64" => "amd64",
+        _ => arch, // arm64 stays as "arm64" in amd64/arm64 convention
+    };
+    let x86_64_arch = match arch {
+        "x64" => "x86_64",
+        "arm64" => "aarch64",
+        _ => arch,
+    };
+    // GNU-style arch: x64 -> x86_64, arm64 stays arm64 (used by opam, etc.)
+    let gnu_arch = match arch {
+        "x64" => "x86_64",
+        _ => arch,
+    };
+
+    template
+        .replace("{version}", version)
+        .replace("{os}", os)
+        .replace("{arch}", arch)
+        // Common aliases
+        .replace("{darwin_os}", darwin_os)
+        .replace("{amd64_arch}", amd64_arch)
+        .replace("{x86_64_arch}", x86_64_arch)
+        .replace("{gnu_arch}", gnu_arch)
 }
 
 #[cfg(test)]
