@@ -1,14 +1,16 @@
 use crate::backend::Backend;
 use crate::backend::backend_type::BackendType;
+use crate::backend::platform_target::PlatformTarget;
 use crate::cli::args::BackendArg;
 use crate::cmd::CmdLineRunner;
 use crate::config::Config;
 use crate::config::Settings;
 use crate::install_context::InstallContext;
 use crate::timeout;
-use crate::toolset::ToolVersion;
+use crate::toolset::{ToolRequest, ToolVersion};
 use async_trait::async_trait;
 use itertools::Itertools;
+use std::collections::BTreeMap;
 use std::{fmt::Debug, sync::Arc};
 use xx::regex;
 
@@ -68,9 +70,17 @@ impl Backend for GoBackend {
 
                 for i in indices {
                     let mod_path = parts[..=i].join("/");
-                    let res = cmd!("go", "list", "-m", "-versions", "-json", mod_path)
-                        .full_env(self.dependency_env(config).await?)
-                        .read();
+                    let res = cmd!(
+                        "go",
+                        "list",
+                        "-mod=readonly",
+                        "-m",
+                        "-versions",
+                        "-json",
+                        mod_path
+                    )
+                    .full_env(self.dependency_env(config).await?)
+                    .read();
                     if let Ok(raw) = res {
                         let res = serde_json::from_str::<GoModInfo>(&raw);
                         if let Ok(mut mod_info) = res {
@@ -110,7 +120,7 @@ impl Backend for GoBackend {
         let opts = self.ba.opts();
 
         let install = async |v| {
-            let mut cmd = CmdLineRunner::new("go").arg("install");
+            let mut cmd = CmdLineRunner::new("go").arg("install").arg("-mod=readonly");
 
             if let Some(tags) = opts.get("tags") {
                 cmd = cmd.arg("-tags").arg(tags);
@@ -138,6 +148,22 @@ impl Backend for GoBackend {
 
         Ok(tv)
     }
+
+    fn resolve_lockfile_options(
+        &self,
+        request: &ToolRequest,
+        _target: &PlatformTarget,
+    ) -> BTreeMap<String, String> {
+        let opts = request.options();
+        let mut result = BTreeMap::new();
+
+        // tags affect compilation
+        if let Some(value) = opts.get("tags") {
+            result.insert("tags".to_string(), value.clone());
+        }
+
+        result
+    }
 }
 
 impl GoBackend {
