@@ -4,6 +4,7 @@ use crate::backend::static_helpers::{
     clean_binary_name, get_filename_from_url, list_available_platforms_with_key,
     lookup_platform_key, template_string, verify_artifact,
 };
+use crate::backend::version_list;
 use crate::cli::args::BackendArg;
 use crate::config::Config;
 use crate::config::Settings;
@@ -51,7 +52,9 @@ impl HttpBackend {
         // Include extraction options in cache key to handle different extraction needs
         let mut cache_key_parts = vec![checksum.clone()];
 
-        if let Some(strip_components) = opts.get("strip_components") {
+        let strip_components = lookup_platform_key(opts, "strip_components")
+            .or_else(|| opts.get("strip_components").cloned());
+        if let Some(strip_components) = strip_components {
             cache_key_parts.push(format!("strip_{strip_components}"));
         }
 
@@ -151,7 +154,9 @@ impl HttpBackend {
         opts: &ToolVersionOptions,
         pr: Option<&dyn SingleReport>,
     ) -> Result<()> {
-        let mut strip_components = opts.get("strip_components").and_then(|s| s.parse().ok());
+        let mut strip_components = lookup_platform_key(opts, "strip_components")
+            .or_else(|| opts.get("strip_components").cloned())
+            .and_then(|s| s.parse().ok());
 
         file::create_dir_all(cache_path)?;
 
@@ -378,6 +383,24 @@ impl HttpBackend {
         }
         Ok(())
     }
+
+    /// Fetch and parse versions from a version list URL
+    async fn fetch_versions_from_url(&self) -> Result<Vec<String>> {
+        let opts = self.ba.opts();
+
+        // Get version_list_url from options
+        let version_list_url = match opts.get("version_list_url") {
+            Some(url) => url.clone(),
+            None => return Ok(vec![]),
+        };
+
+        // Get optional version regex pattern or JSON path
+        let version_regex = opts.get("version_regex").map(|s| s.as_str());
+        let version_json_path = opts.get("version_json_path").map(|s| s.as_str());
+
+        // Use the version_list module to fetch and parse versions
+        version_list::fetch_versions(&version_list_url, version_regex, version_json_path).await
+    }
 }
 
 #[async_trait]
@@ -391,8 +414,8 @@ impl Backend for HttpBackend {
     }
 
     async fn _list_remote_versions(&self, _config: &Arc<Config>) -> Result<Vec<String>> {
-        // Http backend doesn't support remote version listing
-        Ok(vec![])
+        // Fetch versions from version_list_url if configured
+        self.fetch_versions_from_url().await
     }
 
     async fn install_version_(
