@@ -41,18 +41,21 @@ pub mod asdf;
 pub mod asset_detector;
 pub mod backend_type;
 pub mod cargo;
+pub mod conda;
 pub mod dotnet;
 mod external_plugin_cache;
 pub mod gem;
 pub mod github;
 pub mod go;
 pub mod http;
+pub mod jq;
 pub mod npm;
 pub mod pipx;
 pub mod platform_target;
 pub mod spm;
 pub mod static_helpers;
 pub mod ubi;
+pub mod version_list;
 pub mod vfox;
 
 pub type ABackend = Arc<dyn Backend>;
@@ -172,6 +175,7 @@ pub fn arg_to_backend(ba: BackendArg) -> Option<ABackend> {
         BackendType::Aqua => Some(Arc::new(aqua::AquaBackend::from_arg(ba))),
         BackendType::Asdf => Some(Arc::new(asdf::AsdfBackend::from_arg(ba))),
         BackendType::Cargo => Some(Arc::new(cargo::CargoBackend::from_arg(ba))),
+        BackendType::Conda => Some(Arc::new(conda::CondaBackend::from_arg(ba))),
         BackendType::Dotnet => Some(Arc::new(dotnet::DotnetBackend::from_arg(ba))),
         BackendType::Npm => Some(Arc::new(npm::NPMBackend::from_arg(ba))),
         BackendType::Gem => Some(Arc::new(gem::GemBackend::from_arg(ba))),
@@ -213,6 +217,21 @@ pub trait Backend: Debug + Send + Sync {
         format!("{os}-{arch}")
     }
 
+    /// Resolves the lockfile options for a tool request on a target platform.
+    /// These options affect artifact identity and must match exactly for lockfile lookup.
+    ///
+    /// For the current platform: resolves from Settings and ToolRequest options
+    /// For other platforms (cross-platform mise lock): uses sensible defaults
+    ///
+    /// Backends should override this to return options that affect which artifact is downloaded.
+    fn resolve_lockfile_options(
+        &self,
+        _request: &ToolRequest,
+        _target: &PlatformTarget,
+    ) -> BTreeMap<String, String> {
+        BTreeMap::new() // Default: no options affect artifact identity
+    }
+
     async fn description(&self) -> Option<String> {
         None
     }
@@ -498,6 +517,24 @@ pub trait Backend: Debug + Send + Sync {
                 return Ok(tv);
             }
         }
+        // Check for --locked mode: if enabled and no lockfile URL exists, fail early
+        if ctx.locked {
+            let platform_key = self.get_platform_key();
+            let has_lockfile_url = tv
+                .lock_platforms
+                .get(&platform_key)
+                .and_then(|p| p.url.as_ref())
+                .is_some();
+            if !has_lockfile_url {
+                bail!(
+                    "No lockfile URL found for {} on platform {} (--locked mode)\n\
+                    hint: Run `mise lock` to generate lockfile URLs, or disable locked mode",
+                    tv.style(),
+                    platform_key
+                );
+            }
+        }
+
         ctx.pr.set_message("install".into());
         let _lock = lock_file::get(&tv.install_path(), ctx.force)?;
         self.create_install_dirs(&tv)?;
@@ -780,12 +817,22 @@ pub trait Backend: Debug + Send + Sync {
 
     fn fuzzy_match_filter(&self, versions: Vec<String>, query: &str) -> Vec<String> {
         let escaped_query = regex::escape(query);
-        let query = if query == "latest" {
+        let query_pattern = if query == "latest" {
             "v?[0-9].*"
         } else {
             &escaped_query
         };
-        let query_regex = Regex::new(&format!("^{query}([-.].+)?$")).unwrap();
+        let query_regex = Regex::new(&format!("^{query_pattern}([-.].+)?$")).unwrap();
+
+        // Also create a regex without the 'v' prefix if query starts with 'v'
+        // This allows "v1.0.0" to match "1.0.0" in registries that don't use v-prefix
+        let query_without_v_regex = if query.starts_with('v') || query.starts_with('V') {
+            let without_v = regex::escape(&query[1..]);
+            Some(Regex::new(&format!("^{without_v}([-.].+)?$")).unwrap())
+        } else {
+            None
+        };
+
         versions
             .into_iter()
             .filter(|v| {
@@ -795,7 +842,16 @@ pub trait Backend: Debug + Send + Sync {
                 if VERSION_REGEX.is_match(v) {
                     return false;
                 }
-                query_regex.is_match(v)
+                if query_regex.is_match(v) {
+                    return true;
+                }
+                // Try matching without the 'v' prefix
+                if let Some(ref re) = query_without_v_regex
+                    && re.is_match(v)
+                {
+                    return true;
+                }
+                false
             })
             .collect()
     }
@@ -945,7 +1001,6 @@ pub trait Backend: Debug + Send + Sync {
         // 3. Handle any URL-specific logic
         Ok(PlatformInfo {
             checksum: None, // TODO: Implement checksum fetching
-            name: None,     // TODO: Implement name extraction from URL if needed
             size: None,     // TODO: Implement size fetching via HEAD request
             url: Some(tarball_url.to_string()),
             url_api: None,
@@ -965,15 +1020,20 @@ pub trait Backend: Debug + Send + Sync {
         // 1. Query GitHub/GitLab release API
         // 2. Find matching asset for the target platform
         // 3. Extract download URL, size, and checksums
-        let asset_url = release_info.asset_pattern.as_ref().map(|pattern| {
+        let asset_name = release_info.asset_pattern.as_ref().map(|pattern| {
             pattern
                 .replace("{os}", target.os_name())
                 .replace("{arch}", target.arch_name())
         });
 
+        // Combine api_url (base URL) with asset_name to get full download URL
+        let asset_url = match (&release_info.api_url, &asset_name) {
+            (Some(base_url), Some(name)) => Some(format!("{}/{}", base_url, name)),
+            _ => asset_name.clone(),
+        };
+
         Ok(PlatformInfo {
             checksum: None, // TODO: Implement checksum fetching from releases
-            name: None,     // TODO: Implement asset name fetching from releases
             size: None,     // TODO: Implement size fetching from GitHub API
             url: asset_url,
             url_api: None,
@@ -992,7 +1052,6 @@ pub trait Backend: Debug + Send + Sync {
         Ok(PlatformInfo {
             checksum: None,
             size: None,
-            name: None,
             url: None,
             url_api: None,
         })
@@ -1023,10 +1082,18 @@ pub fn unalias_backend(backend: &str) -> &str {
     match backend {
         "nodejs" => "node",
         "golang" => "go",
-        _ => backend,
+        _ => backend.trim_start_matches("core:"),
     }
 }
 
+#[test]
+fn test_unalias_backend() {
+    assert_eq!(unalias_backend("node"), "node");
+    assert_eq!(unalias_backend("nodejs"), "node");
+    assert_eq!(unalias_backend("core:node"), "node");
+    assert_eq!(unalias_backend("golang"), "go");
+}
+
 impl Display for dyn Backend {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}", self.id())
