@@ -1,4 +1,5 @@
 // Shared template logic for backends
+use crate::backend::platform_target::PlatformTarget;
 use crate::file;
 use crate::hash;
 use crate::toolset::ToolVersion;
@@ -19,15 +20,56 @@ const ARCH_PATTERNS: &[&str] = &[
     "riscv64", "s390x", "i686", "i386", "x64", "mips", "arm", "x86",
 ];
 
+pub trait VerifiableError: Sized + Send + Sync + 'static {
+    fn is_not_found(&self) -> bool;
+    fn into_eyre(self) -> eyre::Report;
+}
+
+impl VerifiableError for eyre::Report {
+    fn is_not_found(&self) -> bool {
+        self.chain().any(|cause| {
+            if let Some(err) = cause.downcast_ref::<reqwest::Error>() {
+                err.status() == Some(reqwest::StatusCode::NOT_FOUND)
+            } else {
+                false
+            }
+        })
+    }
+
+    fn into_eyre(self) -> eyre::Report {
+        self
+    }
+}
+
+impl VerifiableError for anyhow::Error {
+    fn is_not_found(&self) -> bool {
+        if self.to_string().contains("404") {
+            return true;
+        }
+        self.chain().any(|cause| {
+            if let Some(err) = cause.downcast_ref::<reqwest::Error>() {
+                err.status() == Some(reqwest::StatusCode::NOT_FOUND)
+            } else {
+                false
+            }
+        })
+    }
+
+    fn into_eyre(self) -> eyre::Report {
+        eyre::eyre!(self)
+    }
+}
+
 /// Helper to try both prefixed and non-prefixed tags for a resolver function
-pub async fn try_with_v_prefix<F, Fut, T>(
+pub async fn try_with_v_prefix<F, Fut, T, E>(
     version: &str,
     version_prefix: Option<&str>,
     resolver: F,
 ) -> Result<T>
 where
     F: Fn(String) -> Fut,
-    Fut: std::future::Future<Output = Result<T>>,
+    Fut: Future<Output = std::result::Result<T, E>>,
+    E: VerifiableError,
 {
     let mut errors = vec![];
 
@@ -42,27 +84,23 @@ where
         } else {
             vec![format!("{}{}", prefix, version), version.to_string()]
         }
+    } else if version.starts_with('v') {
+        vec![
+            version.to_string(),
+            version.trim_start_matches('v').to_string(),
+        ]
     } else {
-        // Fall back to 'v' prefix logic
-        if version.starts_with('v') {
-            vec![
-                version.to_string(),
-                version.trim_start_matches('v').to_string(),
-            ]
-        } else {
-            vec![format!("v{version}"), version.to_string()]
-        }
+        vec![format!("v{version}"), version.to_string()]
     };
 
     for candidate in candidates {
-        match resolver(candidate.clone()).await {
+        match resolver(candidate).await {
             Ok(res) => return Ok(res),
             Err(e) => {
-                let is_404 = crate::http::error_code(&e) == Some(404);
-                if is_404 {
-                    errors.push(e);
+                if e.is_not_found() {
+                    errors.push(e.into_eyre());
                 } else {
-                    return Err(e);
+                    return Err(e.into_eyre());
                 }
             }
         }
@@ -124,6 +162,60 @@ pub fn lookup_platform_key(opts: &ToolVersionOptions, key_type: &str) -> Option<
     None
 }
 
+/// Returns all possible aliases for a given platform target (os, arch).
+fn target_platform_aliases(target: &PlatformTarget) -> Vec<(String, String)> {
+    let os = target.os_name();
+    let arch = target.arch_name();
+    let mut aliases = vec![];
+
+    // OS aliases
+    let os_aliases = match os {
+        "macos" | "darwin" => vec!["macos", "darwin"],
+        "linux" => vec!["linux"],
+        "windows" => vec!["windows"],
+        _ => vec![os],
+    };
+
+    // Arch aliases
+    let arch_aliases = match arch {
+        "x64" | "amd64" | "x86_64" => vec!["x64", "amd64", "x86_64"],
+        "arm64" | "aarch64" => vec!["arm64", "aarch64"],
+        _ => vec![arch],
+    };
+
+    for os in &os_aliases {
+        for arch in &arch_aliases {
+            aliases.push((os.to_string(), arch.to_string()));
+        }
+    }
+    aliases
+}
+
+/// Looks up a value in ToolVersionOptions for a specific target platform.
+/// Used for cross-platform lockfile generation.
+pub fn lookup_platform_key_for_target(
+    opts: &ToolVersionOptions,
+    key_type: &str,
+    target: &PlatformTarget,
+) -> Option<String> {
+    // Try nested platform structure with os-arch format
+    for (os, arch) in target_platform_aliases(target) {
+        for prefix in ["platforms", "platform"] {
+            // Try nested format: platforms.macos-x64.url
+            let nested_key = format!("{prefix}.{os}-{arch}.{key_type}");
+            if let Some(val) = opts.get_nested_string(&nested_key) {
+                return Some(val);
+            }
+            // Try flat format: platforms_macos_arm64_url
+            let flat_key = format!("{prefix}_{os}_{arch}_{key_type}");
+            if let Some(val) = opts.get(&flat_key) {
+                return Some(val.clone());
+            }
+        }
+    }
+    None
+}
+
 /// Lists platform keys (e.g. "macos-x64") for which a given key_type exists (e.g. "url").
 pub fn list_available_platforms_with_key(opts: &ToolVersionOptions, key_type: &str) -> Vec<String> {
     let mut set = IndexSet::new();
@@ -193,7 +285,9 @@ pub fn install_artifact(
     pr: Option<&dyn SingleReport>,
 ) -> eyre::Result<()> {
     let install_path = tv.install_path();
-    let mut strip_components = opts.get("strip_components").and_then(|s| s.parse().ok());
+    let mut strip_components = lookup_platform_key(opts, "strip_components")
+        .or_else(|| opts.get("strip_components").cloned())
+        .and_then(|s| s.parse().ok());
 
     file::remove_all(&install_path)?;
     file::create_dir_all(&install_path)?;
@@ -288,6 +382,13 @@ pub fn install_artifact(
 
         // Extract with determined strip_components
         file::untar(file_path, &install_path, &tar_opts)?;
+
+        // Handle rename_exe option for archives
+        if let Some(rename_to) =
+            lookup_platform_key(opts, "rename_exe").or_else(|| opts.get("rename_exe").cloned())
+        {
+            rename_executable_in_dir(&install_path, &rename_to)?;
+        }
     }
     Ok(())
 }
@@ -336,6 +437,38 @@ pub fn verify_checksum_str(
     Ok(())
 }
 
+/// Renames the first executable file found in a directory to a new name.
+/// Used by the `rename_exe` option to rename binaries after archive extraction.
+fn rename_executable_in_dir(dir: &Path, new_name: &str) -> eyre::Result<()> {
+    let target_path = dir.join(new_name);
+
+    // Check if target already exists before iterating
+    // (read_dir order is non-deterministic, so we must check first)
+    if target_path.is_file() && crate::file::is_executable(&target_path) {
+        return Ok(());
+    }
+
+    // Find executables in the directory (non-recursive for top level)
+    for entry in std::fs::read_dir(dir)?.flatten() {
+        let path = entry.path();
+        if path.is_file() && crate::file::is_executable(&path) {
+            let file_name = path.file_name().unwrap().to_string_lossy();
+            // Skip common non-binary files
+            if file_name.starts_with('.')
+                || file_name.ends_with(".txt")
+                || file_name.ends_with(".md")
+            {
+                continue;
+            }
+            // Rename this executable
+            std::fs::rename(&path, &target_path)?;
+            debug!("Renamed {} to {}", path.display(), target_path.display());
+            return Ok(());
+        }
+    }
+    Ok(())
+}
+
 /// Cleans a binary name by removing OS/arch suffixes and version numbers.
 /// This is useful when downloading single binaries that have platform-specific names.
 /// Executable extensions (.exe, .bat, .sh, etc.) are preserved.
