@@ -1,4 +1,5 @@
 use crate::backend::backend_type::BackendType;
+use crate::backend::platform_target::PlatformTarget;
 use crate::backend::static_helpers::{lookup_platform_key, try_with_v_prefix};
 use crate::cli::args::BackendArg;
 use crate::config::{Config, Settings};
@@ -7,13 +8,14 @@ use crate::env::{
 };
 use crate::install_context::InstallContext;
 use crate::plugins::VERSION_REGEX;
-use crate::toolset::ToolVersion;
+use crate::toolset::{ToolRequest, ToolVersion};
 use crate::{backend::Backend, toolset::ToolVersionOptions};
 use crate::{file, github, gitlab, hash};
 use async_trait::async_trait;
 use eyre::bail;
 use itertools::Itertools;
 use regex::Regex;
+use std::collections::BTreeMap;
 use std::path::Path;
 use std::str::FromStr;
 use std::sync::Arc;
@@ -51,6 +53,7 @@ impl Backend for UbiBackend {
                 None => match forge {
                     ForgeType::GitHub => github::API_URL,
                     ForgeType::GitLab => gitlab::API_URL,
+                    _ => bail!("Unsupported forge type {:?}", forge),
                 },
             };
             let tag_regex = OnceLock::new();
@@ -65,6 +68,7 @@ impl Backend for UbiBackend {
                     .into_iter()
                     .map(|r| r.tag_name)
                     .collect::<Vec<String>>(),
+                _ => bail!("Unsupported forge type {:?}", forge),
             };
             if versions.is_empty() {
                 match forge {
@@ -80,6 +84,7 @@ impl Backend for UbiBackend {
                             .into_iter()
                             .collect();
                     }
+                    _ => bail!("Unsupported forge type {:?}", forge),
                 }
             }
 
@@ -109,6 +114,13 @@ impl Backend for UbiBackend {
         ctx: &InstallContext,
         mut tv: ToolVersion,
     ) -> eyre::Result<ToolVersion> {
+        // Check if lockfile has URL for this platform
+        let platform_key = self.get_platform_key();
+        let lockfile_url = tv
+            .lock_platforms
+            .get(&platform_key)
+            .and_then(|p| p.url.clone());
+
         let v = tv.version.to_string();
         let opts = tv.request.options();
         let bin_path = lookup_platform_key(&opts, "bin_path")
@@ -117,8 +129,15 @@ impl Backend for UbiBackend {
         let extract_all = opts.get("extract_all").is_some_and(|v| v == "true");
         let bin_dir = tv.install_path();
 
-        if name_is_url(&self.tool_name()) {
-            install(&self.tool_name(), &v, &bin_dir, extract_all, &opts).await?;
+        // Use lockfile URL if available, otherwise fall back to standard resolution
+        if let Some(url) = &lockfile_url {
+            install(url, &v, &bin_dir, extract_all, &opts)
+                .await
+                .map_err(|e| eyre::eyre!(e))?;
+        } else if name_is_url(&self.tool_name()) {
+            install(&self.tool_name(), &v, &bin_dir, extract_all, &opts)
+                .await
+                .map_err(|e| eyre::eyre!(e))?;
         } else {
             try_with_v_prefix(&v, None, |candidate| {
                 let opts = opts.clone();
@@ -255,6 +274,24 @@ impl Backend for UbiBackend {
             }
         }
     }
+
+    fn resolve_lockfile_options(
+        &self,
+        request: &ToolRequest,
+        _target: &PlatformTarget,
+    ) -> BTreeMap<String, String> {
+        let opts = request.options();
+        let mut result = BTreeMap::new();
+
+        // These options affect which artifact is downloaded
+        for key in ["exe", "matching", "matching_regex", "provider"] {
+            if let Some(value) = opts.get(key) {
+                result.insert(key.to_string(), value.clone());
+            }
+        }
+
+        result
+    }
 }
 
 impl UbiBackend {
@@ -281,6 +318,7 @@ fn set_token<'a>(mut builder: UbiBuilder<'a>, forge: &ForgeType) -> UbiBuilder<'
             }
             builder
         }
+        _ => builder,
     }
 }
 
@@ -298,6 +336,7 @@ fn set_enterprise_token<'a>(mut builder: UbiBuilder<'a>, forge: &ForgeType) -> U
             }
             builder
         }
+        _ => builder,
     }
 }
 
@@ -307,7 +346,7 @@ async fn install(
     bin_dir: &Path,
     extract_all: bool,
     opts: &ToolVersionOptions,
-) -> eyre::Result<()> {
+) -> anyhow::Result<()> {
     let mut builder = UbiBuilder::new().install_dir(bin_dir);
 
     if name_is_url(name) {
@@ -349,7 +388,7 @@ async fn install(
         builder = set_enterprise_token(builder, &forge);
     }
 
-    let mut ubi = builder.build().map_err(|e| eyre::eyre!(e))?;
+    let mut ubi = builder.build()?;
 
     // TODO: hacky but does not compile without it
     tokio::task::block_in_place(|| {
@@ -359,11 +398,6 @@ async fn install(
                 .build()
                 .unwrap()
         });
-        RT.block_on(async {
-            match ubi.install_binary().await {
-                Ok(_) => Ok(()),
-                Err(e) => Err(eyre::eyre!(e)),
-            }
-        })
+        RT.block_on(async { ubi.install_binary().await })
     })
 }
