@@ -13,7 +13,7 @@ use crate::cli::args::ToolArg;
 use crate::cmd;
 use crate::config::{Config, Settings};
 use crate::env;
-use crate::toolset::{InstallOptions, ToolsetBuilder};
+use crate::toolset::{InstallOptions, ResolveOptions, ToolsetBuilder};
 
 /// Execute a command with tool(s) set
 ///
@@ -55,13 +55,32 @@ impl Exec {
     #[async_backtrace::framed]
     pub async fn run(self) -> eyre::Result<()> {
         let mut config = Config::get().await?;
+
+        // Check if any tool arg explicitly specified @latest
+        // If so, resolve to the actual latest version from the registry (not just latest installed)
+        let has_explicit_latest = self
+            .tool
+            .iter()
+            .any(|t| t.tvr.as_ref().is_some_and(|tvr| tvr.version() == "latest"));
+
+        let resolve_options = if has_explicit_latest {
+            ResolveOptions {
+                latest_versions: true,
+                use_locked_version: false,
+            }
+        } else {
+            Default::default()
+        };
+
         let mut ts = measure!("toolset", {
             ToolsetBuilder::new()
                 .with_args(&self.tool)
                 .with_default_to_latest(true)
+                .with_resolve_options(resolve_options.clone())
                 .build(&config)
                 .await?
         });
+
         let opts = InstallOptions {
             force: false,
             jobs: self.jobs,
@@ -73,18 +92,29 @@ impl Exec {
                 || !Settings::get().exec_auto_install
                 || *env::__MISE_SHIM,
             skip_auto_install: !Settings::get().exec_auto_install || !Settings::get().auto_install,
-            resolve_options: Default::default(),
+            resolve_options,
             ..Default::default()
         };
         measure!("install_arg_versions", {
             ts.install_missing_versions(&mut config, &opts).await?
         });
+
+        // If we installed new versions for explicit @latest, re-resolve to pick up the installed versions
+        if has_explicit_latest {
+            ts.resolve_with_opts(&config, &opts.resolve_options).await?;
+        }
+
         measure!("notify_if_versions_missing", {
             ts.notify_if_versions_missing(&config).await;
         });
 
         let (program, mut args) = parse_command(&env::SHELL, &self.command, &self.c);
-        let env = measure!("env_with_path", { ts.env_with_path(&config).await? });
+        let mut env = measure!("env_with_path", { ts.env_with_path(&config).await? });
+
+        // Ensure MISE_ENV is set in the spawned shell if it was specified via -E flag
+        if !env::MISE_ENV.is_empty() {
+            env.insert("MISE_ENV".to_string(), env::MISE_ENV.join(","));
+        }
 
         if program.rsplit('/').next() == Some("fish") {
             let mut cmd = vec![];
@@ -151,8 +181,9 @@ where
 
     let res = cmd.unchecked().run()?;
     match res.status.code() {
-        Some(0) => Ok(()),
-        Some(code) => Err(eyre!("command failed: exit code {}", code)),
+        Some(code) => {
+            std::process::exit(code);
+        }
         None => Err(eyre!("command failed: terminated by signal")),
     }
 }
