@@ -4,7 +4,7 @@ use crate::task::TaskOutput;
 use crate::ui::{self, ctrlc};
 use crate::{Result, backend};
 use crate::{cli::args::ToolArg, path::PathExt};
-use crate::{logger, migrate, shims};
+use crate::{hook_env as hook_env_module, logger, migrate, shims};
 use clap::{ArgAction, CommandFactory, Parser, Subcommand};
 use eyre::bail;
 use std::path::PathBuf;
@@ -166,6 +166,13 @@ pub struct Cli {
     /// Read/write directly to stdin/stdout/stderr instead of by line
     #[clap(long, global = true)]
     pub raw: bool,
+    /// Require lockfile URLs to be present during installation
+    ///
+    /// Fails if tools don't have pre-resolved URLs in the lockfile for the current platform.
+    /// This prevents API calls to GitHub, aqua registry, etc.
+    /// Can also be enabled via MISE_LOCKED=1 or settings.locked=true
+    #[clap(long, global = true, verbatim_doc_comment)]
+    pub locked: bool,
     /// Suppress all task output and mise non-error messages
     #[clap(long, global = true, overrides_with_all = &["quiet", "trace", "verbose", "debug", "log_level"])]
     pub silent: bool,
@@ -433,6 +440,11 @@ impl Cli {
         if *crate::env::MISE_TOOL_STUB && args.len() >= 2 {
             tool_stub::short_circuit_stub(&args[2..]).await?;
         }
+        // Fast-path for hook-env: exit early if nothing has changed
+        // This avoids expensive backend::load_tools() and config loading
+        if hook_env_module::should_exit_early_fast() {
+            return Ok(());
+        }
         measure!("logger", { logger::init() });
         check_working_directory();
         measure!("handle_shim", { shims::handle_shim().await })?;
