@@ -3,8 +3,8 @@ use std::{collections::BTreeMap, sync::Arc};
 
 use crate::Result;
 use crate::backend::Backend;
+use crate::backend::platform_target::PlatformTarget;
 use crate::cli::args::BackendArg;
-use crate::cli::version::OS;
 use crate::cmd::CmdLineRunner;
 use crate::config::{Config, Settings};
 use crate::file::{TarFormat, TarOptions};
@@ -96,15 +96,13 @@ impl GoPlugin {
 
     async fn download(&self, tv: &mut ToolVersion, pr: &dyn SingleReport) -> eyre::Result<PathBuf> {
         let settings = Settings::get();
-        let filename = format!(
-            "go{}.{}-{}.{}",
-            tv.version,
-            platform(),
-            arch(&settings),
-            ext()
+        let tarball_url = Arc::new(
+            self.get_tarball_url(tv, &PlatformTarget::from_current())
+                .await?
+                .ok_or_else(|| eyre::eyre!("Failed to get go tarball URL"))?,
         );
-        let tarball_url = Arc::new(format!("{}/{}", &settings.go_download_mirror, &filename));
-        let tarball_path = tv.download_path().join(&filename);
+        let filename = tarball_url.split('/').next_back().unwrap();
+        let tarball_path = tv.download_path().join(filename);
 
         let tarball_url_ = tarball_url.clone();
         let checksum_handle = tokio::spawn(async move {
@@ -265,26 +263,34 @@ impl Backend for GoPlugin {
     ) -> eyre::Result<BTreeMap<String, String>> {
         self._exec_env(tv)
     }
-}
 
-fn platform() -> &'static str {
-    if cfg!(target_os = "macos") {
-        "darwin"
-    } else {
-        &OS
+    async fn get_tarball_url(
+        &self,
+        tv: &ToolVersion,
+        target: &PlatformTarget,
+    ) -> Result<Option<String>> {
+        let settings = Settings::get();
+        let platform = match target.os_name() {
+            "macos" => "darwin",
+            "linux" => "linux",
+            "windows" => "windows",
+            _ => "linux",
+        };
+        let arch = match target.arch_name() {
+            "x64" => "amd64",
+            "arm64" => "arm64",
+            "arm" => "armv6l",
+            "riscv64" => "riscv64",
+            other => other,
+        };
+        let ext = if target.os_name() == "windows" {
+            "zip"
+        } else {
+            "tar.gz"
+        };
+        Ok(Some(format!(
+            "{}/go{}.{}-{}.{}",
+            &settings.go_download_mirror, tv.version, platform, arch, ext
+        )))
     }
 }
-
-fn arch(settings: &Settings) -> &str {
-    match settings.arch() {
-        "x64" => "amd64",
-        "arm64" => "arm64",
-        "arm" => "armv6l",
-        "riscv64" => "riscv64",
-        other => other,
-    }
-}
-
-fn ext() -> &'static str {
-    if cfg!(windows) { "zip" } else { "tar.gz" }
-}
