@@ -52,11 +52,32 @@ impl Shell for Nushell {
 
         let mut out = String::new();
 
-        out.push_str(&shell::build_deactivation_script(self));
+        out.push_str(&formatdoc! {r#"
+          def "parse vars" [] {{
+            $in | from csv --noheaders --no-infer | rename 'op' 'name' 'value'
+          }}
+
+          def --env "update-env" [] {{
+            for $var in $in {{
+              if $var.op == "set" {{
+                if ($var.name | str upcase) == 'PATH' {{
+                  $env.PATH = ($var.value | split row (char esep))
+                }} else {{
+                  load-env {{($var.name): $var.value}}
+                }}
+              }} else if $var.op == "hide" and $var.name in $env {{
+                hide-env $var.name
+              }}
+            }}
+          }}
+        "#});
+
+        let deactivation_ops_csv = &shell::build_deactivation_script(self);
         let inline_prelude = self.format_activate_prelude_inline(&opts.prelude);
         out.push_str(&formatdoc! {r#"
           export-env {{
             {inline_prelude}
+            "{deactivation_ops_csv}" | parse vars | update-env
             $env.MISE_SHELL = "nu"
             let mise_hook = {{
               condition: {{ "MISE_SHELL" in $env }}
@@ -73,10 +94,6 @@ impl Shell for Nushell {
             $env.config = ($old_config | upsert $field ($old_hooks ++ [$new_hook]))
           }}
 
-          def "parse vars" [] {{
-            $in | from csv --noheaders --no-infer | rename 'op' 'name' 'value'
-          }}
-
           export def --env --wrapped main [command?: string, --help, ...rest: string] {{
             let commands = ["deactivate", "shell", "sh"]
 
@@ -93,20 +110,6 @@ impl Shell for Nushell {
             }}
           }}
 
-          def --env "update-env" [] {{
-            for $var in $in {{
-              if $var.op == "set" {{
-                if ($var.name | str upcase) == 'PATH' {{
-                  $env.PATH = ($var.value | split row (char esep))
-                }} else {{
-                  load-env {{($var.name): $var.value}}
-                }}
-              }} else if $var.op == "hide" {{
-                hide-env $var.name
-              }}
-            }}
-          }}
-
           def --env mise_hook [] {{
             ^"{exe}" hook-env{flags} -s nu
               | parse vars
