@@ -2,7 +2,22 @@ use std::sync::mpsc;
 use std::thread;
 use std::time::Duration;
 
-use color_eyre::eyre::{Context, Result};
+use crate::ui::time::format_duration;
+use color_eyre::eyre::{Report, Result};
+use std::fmt::{Display, Formatter};
+
+#[derive(Debug, Clone, Copy)]
+pub struct TimeoutError {
+    pub duration: Duration,
+}
+
+impl Display for TimeoutError {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "timed out after {}", format_duration(self.duration))
+    }
+}
+
+impl std::error::Error for TimeoutError {}
 
 pub fn run_with_timeout<F, T>(f: F, timeout: Duration) -> Result<T>
 where
@@ -16,8 +31,11 @@ where
             // If sending fails, the timeout has already been reached.
             let _ = tx.send(result);
         });
-        rx.recv_timeout(timeout).context("timed out")
-    })?
+        let recv: Result<T> = rx
+            .recv_timeout(timeout)
+            .map_err(|_| Report::from(TimeoutError { duration: timeout }))?;
+        recv
+    })
 }
 
 pub async fn run_with_timeout_async<F, Fut, T>(f: F, timeout: Duration) -> Result<T>
@@ -29,6 +47,6 @@ where
     match tokio::time::timeout(timeout, f()).await {
         Ok(Ok(output)) => Ok(output),
         Ok(Err(e)) => Err(e),
-        Err(_) => Err(eyre::eyre!("timed out")),
+        Err(_) => Err(TimeoutError { duration: timeout }.into()),
     }
 }
