@@ -64,6 +64,8 @@ pub struct InstallOptions {
     pub auto_install_disable_tools: Option<Vec<String>>,
     pub resolve_options: ResolveOptions,
     pub dry_run: bool,
+    /// require lockfile URLs to be present; fail if not
+    pub locked: bool,
 }
 
 impl Default for InstallOptions {
@@ -78,6 +80,7 @@ impl Default for InstallOptions {
             auto_install_disable_tools: Settings::get().auto_install_disable_tools.clone(),
             resolve_options: Default::default(),
             dry_run: false,
+            locked: Settings::get().locked,
         }
     }
 }
@@ -125,15 +128,24 @@ impl Toolset {
     }
     #[async_backtrace::framed]
     pub async fn resolve(&mut self, config: &Arc<Config>) -> eyre::Result<()> {
+        self.resolve_with_opts(config, &Default::default()).await
+    }
+
+    #[async_backtrace::framed]
+    pub async fn resolve_with_opts(
+        &mut self,
+        config: &Arc<Config>,
+        opts: &ResolveOptions,
+    ) -> eyre::Result<()> {
         self.list_missing_plugins();
         let versions = self
             .versions
             .clone()
             .into_iter()
-            .map(|(ba, tvl)| (config.clone(), ba, tvl.clone()))
+            .map(|(ba, tvl)| (config.clone(), ba, tvl.clone(), opts.clone()))
             .collect::<Vec<_>>();
-        let tvls = parallel::parallel(versions, |(config, ba, mut tvl)| async move {
-            if let Err(err) = tvl.resolve(&config, &Default::default()).await {
+        let tvls = parallel::parallel(versions, |(config, ba, mut tvl, opts)| async move {
+            if let Err(err) = tvl.resolve(&config, &opts).await {
                 warn!("Failed to resolve tool version list for {ba}: {err}");
             }
             Ok((ba, tvl))
@@ -462,6 +474,7 @@ impl Toolset {
                             pr: mpr.add_with_options(&tv.style(), opts.dry_run),
                             force: opts.force,
                             dry_run: opts.dry_run,
+                            locked: opts.locked,
                         };
                         // Avoid wrapping the backend error here so the error location
                         // points to the backend implementation (more helpful for debugging).
